@@ -1,6 +1,7 @@
 #include "summarize.h"
 #include "rayOLS.h"
 #include "preprocess.h"
+#include "fitLSYS.h"
 
 #include <R_ext/Rdynload.h>
 
@@ -8,6 +9,7 @@ static const R_CallMethodDef callMethods[] = {
     {"summarize", (DL_FUNC) &summarize, 1},
     {"rayOLS", (DL_FUNC) &rayOLS, 2},
     {"preprocess", (DL_FUNC) &preprocess, 5},
+    {"fitLSYS", (DL_FUNC) &fitLSYS, 7},
     {NULL, NULL, 0}
 };
 
